aboutsummaryrefslogtreecommitdiffstats
path: root/src/tag/TagType.h
diff options
context:
space:
mode:
authorMax Kellermann <max@duempel.org>2013-10-20 13:32:59 +0200
committerMax Kellermann <max@duempel.org>2013-10-20 13:32:59 +0200
commita78b2d84ed7c2a82c69c56125036e70b009a87b0 (patch)
treec8818c4111e9f2138cb66a38e1664ad5aa432bd4 /src/tag/TagType.h
parentcf4d80fc655a399615529bdd27e0be284754c5ab (diff)
downloadmpd-a78b2d84ed7c2a82c69c56125036e70b009a87b0.tar.gz
mpd-a78b2d84ed7c2a82c69c56125036e70b009a87b0.tar.xz
mpd-a78b2d84ed7c2a82c69c56125036e70b009a87b0.zip
TagType: rename enum tag_type to TagType
Diffstat (limited to 'src/tag/TagType.h')
-rw-r--r--src/tag/TagType.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/tag/TagType.h b/src/tag/TagType.h
index 118d66a02..0b8aa55d4 100644
--- a/src/tag/TagType.h
+++ b/src/tag/TagType.h
@@ -27,7 +27,7 @@
/**
* Codes for the type of a tag item.
*/
-enum tag_type
+enum TagType
#ifdef __cplusplus
/* the size of this enum is 1 byte; this is only relevant for C++
code; the only C sources including this header don't use instances
@@ -59,7 +59,7 @@ enum tag_type
};
/**
* An array of strings, which map the #tag_type to its machine
* readable name (specific to the MPD protocol).
*/
extern const char *const tag_item_names[];
@@ -59,7 +59,7 @@ enum tag_type
};
/**
- * An array of strings, which map the #tag_type to its machine
+ * An array of strings, which map the #TagType to its machine
* readable name (specific to the MPD protocol).
*/